@@ -27,7 +27,7 @@ rats <- function(mrs_data, ref = NULL, xlim = c(4, 0.5), max_shift = 20,
                  basis_type = "poly", rescale_output = TRUE,
                  phase_corr = TRUE, ret_corr_only = FALSE) {
   
-  if (class(mrs_data) == "list") {
+  if (inherits(mrs_data, "list")) {
     res <- lapply(mrs_data, rats, ref = ref, xlim = xlim, max_shift = max_shift,
                   p_deg = p_deg, sp_N = sp_N, sp_deg = sp_deg, max_t = max_t,
                   basis_type = basis_type, rescale_output = rescale_output,
